==> p2pd-3.0.0.tar.gz: p2pd-3.0.0/p2pd/do_imports.py <==

import os
import warnings

if __name__ != '__main__':
    os.environ["PYTHONIOENCODING"] = "utf-8"

    from .errors import *
    from .utils import log, what_exception, log_exception, async_test, SelectorEventPolicy, p2pd_setup_event_loop

    from .cmd_tools import *
    from .net import *
    from .bind import *
    from .address import Address
    from .ip_range import IPRange
    from .upnp import port_forward
    from .route_defs import Route, RoutePool
    from .route_utils import get_routes_with_res
    from .pipe_utils import *
    from .interface import Interface, init_p2pd
    from .clock_skew import SysClock
    from .stun_client import STUNClient, get_stun_clients
    from .turn_client import TURNClient
    from .tcp_punch_client import TCPPuncher
    from .daemon import Daemon
    from .echo_server import *
    from .http_client_lib import http_req, ParseHTTPResponse, WebCurl
    from .http_client_lib import http_req_buf
    from .http_server_lib import rest_service, send_json, send_binary, RESTD, api_route_closure
    from .http_server_lib import ParseHTTPRequest
    from .rest_api import P2PDServer, start_p2pd_server, P2PD_PORT
    from .p2p_addr import *
    from .p2p_pipe import *
    from .p2p_node_extra import P2PNodeExtra
    from .p2p_node import P2PNode, NODE_CONF, NODE_PORT
    from .p2p_utils import get_pp_executors
    from .signaling import SignalMock
    from .install import *
    from .toxiclient import ToxiToxic, ToxiTunnel, ToxiClient
    from .toxiserver import ToxiMainServer

    # Will fail if no aiomysql.
    # But PNP server is not needed to use P2PD.
    try:
        from .pnp_server import *
    except:
        pass

    from .pnp_client import *
    from .nickname import *
    from .test_init import *

==> p2pd-3.1.2.tar.gz: p2pd-3.1.2/p2pd/do_imports.py <==

import os
import warnings

if __name__ != '__main__':
    os.environ["PYTHONIOENCODING"] = "utf-8"

    from .errors import *
    from .utils import log, what_exception, log_exception, async_test, SelectorEventPolicy, p2pd_setup_event_loop

    from .cmd_tools import *
    from .net import *
    from .bind import *
    from .address import Address
    from .ip_range import IPRange
    from .upnp import port_forward
    from .route_defs import Route, RoutePool
    from .route_utils import get_routes_with_res
    from .pipe_utils import *
    from .interface import Interface, init_p2pd
    from .clock_skew import SysClock
    from .stun_client import STUNClient, get_stun_clients
    from .turn_client import TURNClient
    from .tcp_punch_client import TCPPuncher
    from .daemon import Daemon
    from .echo_server import *
    from .http_client_lib import ParseHTTPResponse, WebCurl
    from .http_client_lib import http_req_buf
    from .http_server_lib import rest_service, send_json, send_binary, RESTD, api_route_closure
    from .http_server_lib import ParseHTTPRequest
    from .rest_api import P2PDServer, start_p2pd_server, P2PD_PORT
    from .p2p_addr import *
    from .p2p_pipe import *
    from .p2p_node_extra import P2PNodeExtra
    from .p2p_node import P2PNode, NODE_CONF, NODE_PORT
    from .p2p_utils import get_pp_executors
    from .signaling import SignalMock
    from .install import *
    from .toxiclient import ToxiToxic, ToxiTunnel, ToxiClient
    from .toxiserver import ToxiMainServer

    # Will fail if no aiomysql.
    # But PNP server is not needed to use P2PD.
    try:
        from .pnp_server import *
    except:
        pass

    from .pnp_client import *
    from .nickname import *
    from .test_init import *
